domain_puns
Description
This is a small CLI tool I made to help pick out a fun domain from a word or phrase. The goal is to
try to use the top-level domain as part of the word or phrase. For example, instead of
myfavoritecolorisblue.com, myfavoritecoloris.blue would be more fun.
Also, I wrote this to have a chance to learn and use Gleam.
Domains
The domains are sourced from https://data.iana.org/TLD/tlds-alpha-by-domain.txt, which is linked from https://www.icann.org/en/contracted-parties/registry-operators/resources/list-of-top-level-domains.