domain_puns/punycode

Module for working with punycode.

Values

pub fn matches_domain(domain: String) -> Result(String, Nil)

Checks if a domain string is a punycode domain. If it is, it returns the punycode string with the leading prefix for internationalized domains removed.

Search Document